@@ -25,7 +25,7 @@ import ConfigParser
 
 from TrayIcon import TrayIcon
 
-from more import get_sid, get_view_params
+from more import get_sid, get_view_params, _print
 from MainClass import ApiClient
 from calculate.consolegui.datavars import DataVarsGui
 from pid_information import client_pid_info
@@ -39,6 +39,7 @@ class SelectedMethodWgt(QtGui.QWidget):
         self.user_changed_flag = False
         self.lang = args.lang
         self.method = args.method
+        self.skip_options = args.skip_options
 
         # Initialization GUI variables
         self.VarsGui = DataVarsGui()
@@ -46,6 +47,7 @@ class SelectedMethodWgt(QtGui.QWidget):
         self.VarsGui.flIniFile()
 
         self.ClientObj = ApiClient(app, self)
+        self.port = args.port or self.VarsGui.GetInteger('core.cl_core_port')
         self.MethodWidget = self.ClientObj.MainWidget
         self.MethodWidget.topmenu.hide()
         layout = QtGui.QHBoxLayout(self)
@@ -78,7 +80,7 @@ class SelectedMethodWgt(QtGui.QWidget):
         self.show()
 
     def connect(self):
-        self.MethodWidget.connect_to_localhost(self.args.host, self.args.port)
+        self.MethodWidget.connect_to_localhost(self.args.host, self.port)
         if not self.ClientObj.client:
             return 1
         self.ClientObj.sid = get_sid(self.ClientObj.client)
@@ -88,7 +90,7 @@ class SelectedMethodWgt(QtGui.QWidget):
             view = self.ClientObj.client.service[0][self.args.method + \
                                 '_view'](int(self.ClientObj.sid), view_params)
         except sudsds.MethodNotFound:
-            _print ('Method not found: ', self.args.method + '_view')
+            _print('Method not found: ', self.args.method + '_view')
             self.close()
             sys.exit(1)
         if self.ClientObj.method_names.has_key(self.args.method):
@@ -97,7 +99,11 @@ class SelectedMethodWgt(QtGui.QWidget):
             view_method = self.args.method
         self.setWindowTitle(view_method + ' - ' + \
                             self.ClientObj._parent.windowTitle())
-        self.MethodWidget.main_frame_view(view, self.args.method)
+        #self.MethodWidget.MainFrameWgt.call_server_method(False)
+        #self.MethodWidget.main_frame_view(view, self.args.method,
+        #                                    skip_options=not self.args.skip_options)
+        self.MethodWidget.main_frame_view(view, self.args.method,
+                                          skip_options=self.args.skip_options)
         return 0
 
     def translate(self, lang = None):
@@ -105,6 +111,9 @@ class SelectedMethodWgt(QtGui.QWidget):
     def connect_count_changed(self, host, port, count):
         pass
 
+    def has_update(self, update):
+        print "Update", update
+
     def get_size(self):
         self.config = ConfigParser.ConfigParser()
         self.config.read(self.user_config)
@@ -225,25 +234,18 @@ def parse():
     parser.add_argument( 
         '--method', type=str, dest='method', 
         help=_('call method'))
-    parser.add_argument( 
-        '-p', '--port', type=int, default = '8888', dest='port',
+    parser.add_argument(
+        '--skip-options', action='store_true',
+        dest='skip_options', default=False,
+        help=_('run method without options'))
+    parser.add_argument(
+        '-p', '--port', type=int, dest='port',
         help=_('port number'))      
     parser.add_argument( 
         '--host', type=str, default = 'localhost', dest='host',
         help=_('destination host'))
     return parser
 
-class DBusWidget(dbus.service.Object):
-    def __init__(self, name, session, parent):
-        self._parent = parent
-        # export this object to dbus
-        dbus.service.Object.__init__(self, name, session)
-
-    # You can export methods to dbus like you do in python-dbus.
-    @dbus.service.method("org.calculate.consolegui", in_signature='', \
-                         out_signature='')
-    def show(self):
-        self._parent.showNormal()
 
 class MyTabBar(QtGui.QTabBar):
     def __init__(self, _parent):
@@ -343,6 +345,8 @@ class ToolTabWidget(QtGui.QTabWidget):
 
         if not host or host == 'localhost':
             host = '127.0.0.1'
+        if not port:
+            port = self.VarsGui.GetInteger('core.cl_core_port')
         self.FirstWidget.connect_to_localhost(host, port)
         if self.FirstWidget.ClientObj.client:
             if host in ['127.0.0.1', 'localhost']:
